%define major 3
%define minor 68
%define patch 1

%define nspr_version 4.32
Name        : nss
%if %{patch} > 0
Version     : %{major}.%{minor}.%{patch}
%else
Version     : %{major}.%{minor}
%endif
Release: 1
Group       : System Environment/Libraries
License     : MPL-2.0
URL         : https://developer.mozilla.org/en-US/docs/Mozilla/Projects/NSS
Summary     : Network Security Services
Requires    : nspr >= %{nspr_version}

BuildRequires: sqlite3-devel
BuildRequires: nspr-devel

%if %{patch} > 0
Source0: https://ftp.mozilla.org/pub/security/nss/releases/NSS_%{major}_%{minor}_%{patch}_RTM/src/nss-%{version}.tar.gz
%else
Source0: https://ftp.mozilla.org/pub/security/nss/releases/NSS_%{major}_%{minor}_RTM/src/nss-%{version}.tar.gz
%endif

Patch0: nss-pase.patch
Patch1: nss-vfyutil-uninitialized-variable.patch

%description
Network Security Services (NSS) is a set of libraries designed to
support cross-platform development of security-enabled client and
server applications. Applications built with NSS can support SSL v2
and v3, TLS, PKCS #5, PKCS #7, PKCS #11, PKCS #12, S/MIME, X.509
v3 certificates, and other security standards.

%package devel
Summary: Network Security Services Development files
Requires: %{name} = %{version}-%{release}

%description devel
Network Security Services (NSS) is a set of libraries designed to
support cross-platform development of security-enabled client and
server applications. Applications built with NSS can support SSL v2
and v3, TLS, PKCS #5, PKCS #7, PKCS #11, PKCS #12, S/MIME, X.509
v3 certificates, and other security standards.

%prep

%setup -q

%patch0 -p1
%patch1 -p1

%build

cd nss

cat <<EOF > _make
#!/bin/sh

export CC=gcc
export CXX=g++
export NS_USE_GCC=1
export NSS_USE_SYSTEM_SQLITE=1
export NSS_DISABLE_GTESTS=1
export NSPR_INCLUDE_DIR=$(nspr-config --includedir)
export NSPR_LIB_DIR=$(nspr-config --libdir)
export BUILD_OPT=1
export OPT_FLAGS='-DNO_VIZ -I/QOpenSys/pkgs/include'

%ifarch ppc64
export USE_64=1
%endif

make "\$@"
EOF

chmod +x _make

./_make nss_build_all
    
%install

cd nss

mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_libdir}/pkgconfig
mkdir -p %{buildroot}%{_includedir}/nss3

cp -L ../dist/OS400*/lib/libfreebl3.so %{buildroot}%{_libdir}
cp -L ../dist/OS400*/lib/libnss3.so %{buildroot}%{_libdir}
cp -L ../dist/OS400*/lib/libnssutil3.so %{buildroot}%{_libdir}
cp -L ../dist/OS400*/lib/libsmime3.so %{buildroot}%{_libdir}
cp -L ../dist/OS400*/lib/libsoftokn3.so %{buildroot}%{_libdir}
cp -L ../dist/OS400*/lib/libssl3.so %{buildroot}%{_libdir}

cp -L ../dist/OS400*/bin/atob %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/btoa %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/certutil %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/cmsutil %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/crlutil %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/derdump %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/listsuites %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/modutil %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/nss-policy-check %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/ocspclnt %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/pk12util %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/pp %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/selfserv %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/signtool %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/signver %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/ssltap %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/strsclnt %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/tstclnt %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/symkeyutil %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/vfychain %{buildroot}%{_bindir}
cp -L ../dist/OS400*/bin/vfyserv %{buildroot}%{_bindir}

cp -L ../dist/public/nss/*.h %{buildroot}%{_includedir}/nss3


MAJOR=`grep "#define.*NSS_VMAJOR" < lib/nss/nss.h | awk '{print $3}'`
MINOR=`grep "#define.*NSS_VMINOR" < lib/nss/nss.h | awk '{print $3}'`
PATCH=`grep "#define.*NSS_VPATCH" < lib/nss/nss.h | awk '{print $3}'`

sed \
  -e 's|@prefix@|%{_prefix}|' \
  -e "s|@MOD_MAJOR_VERSION@|$MAJOR|" \
  -e "s|@MOD_MINOR_VERSION@|$MINOR|" \
  -e "s|@MOD_PATCH_VERSION@|$PATCH|" \
  -e 's|-Wl,-rpath-link,$libdir ||' \
  pkg/pkg-config/nss-config.in > %{buildroot}%{_bindir}/nss-config

chmod +x %{buildroot}%{_bindir}/nss-config

cat <<EOF > %{buildroot}%{_libdir}/pkgconfig/nss.pc
prefix=%{_prefix}
exec_prefix=\${prefix}
libdir=%{_libdir}
includedir=\${prefix}/include/nss3

Name: NSS
Description: Network Security Services
Version: %{version}
Requires: nspr >= %{nspr_version}
Libs: -lssl3 -lsmime3 -lnss3 -lnssutil3
Cflags: -I\${includedir}
EOF

%files
%defattr(-, qsys, *none)

%{_libdir}/libfreebl3.so
%{_libdir}/libnss3.so
%{_libdir}/libnssutil3.so
%{_libdir}/libsmime3.so 
%{_libdir}/libsoftokn3.so
%{_libdir}/libssl3.so

%{_bindir}/atob
%{_bindir}/btoa
%{_bindir}/certutil
%{_bindir}/cmsutil
%{_bindir}/crlutil
%{_bindir}/derdump
%{_bindir}/listsuites
%{_bindir}/modutil
%{_bindir}/nss-policy-check
%{_bindir}/ocspclnt
%{_bindir}/pk12util
%{_bindir}/pp
%{_bindir}/selfserv
%{_bindir}/signtool
%{_bindir}/signver
%{_bindir}/ssltap
%{_bindir}/strsclnt
%{_bindir}/symkeyutil
%{_bindir}/tstclnt
%{_bindir}/vfychain
%{_bindir}/vfyserv


%files devel
%defattr(-, qsys, *none)

%{_bindir}/nss-config

%{_libdir}/pkgconfig/nss.pc

%{_includedir}/*

%changelog
* Mon Dec 13 2021 Mark Irish <mirish@ibm.com> - 3.68.1
- Update to 3.68.1 to address one vulnerability -
- CVE-2021-43527

* Thu Nov 4 2021 Jason Hansen <stymie@us.ibm.com> - 3.68
- Intra-package Requires need version and release

* Thu Nov 04 2021 Mark Irish <mirish@ibm.com> - 3.68
- Update to version 3.68
- Regenerate patch diffs to account for changes in files

* Wed Nov 27 2019 Kevin Adler <kadler@us.ibm.com> - 3.30
- Use SPDX license identifier
- Update URL

* Tue Mar 13 2018 - Kevin Adler <kadler@us.ibm.com>
- Add more unpackaged binaries

* Tue Mar 13 2018 - Kevin Adler <kadler@us.ibm.com>
- Missing BuildRequires of gawk, use PASE awk instead

* Mon Mar 12 2018 - Kevin Adler <kadler@us.ibm.com>
- Add unshipped files

* Sat Mar 03 2018 - Kevin Adler <kadler@us.ibm.com>
- Add missing BuildRequires
- Let automatic dependency generation pick up sqlite3

* Wed Dec 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Remove 64-bit GCC script workarounds
- OBJECT_MODE now always set by build and install macros

* Tue Nov 07 2017 - Kevin Adler <kadler@us.ibm.com>
- Fix license

* Fri Sep 15 2017 - Kevin Adler <kadler@us.ibm.com>
- NSS requires sqlite3 library

* Fri Sep 15 2017 - Kevin Adler <kadler@us.ibm.com>
- Fix 64-bit build

* Thu Aug 24 2017 - Kevin Adler <kadler@us.ibm.com>
- Acutally build nspr on IBM i

* Mon Jun 05 2017 - Kevin Adler <kadler@us.ibm.com>
- Use make_build and make_install macros

* Sun Apr 23 2017 - Kevin Adler <kadler@us.ibm.com>
- Remove extra space in Summary lines

* Thu Apr 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Initial package, repackaging AIX rpm
